@@ -6,14 +6,17 @@ except ImportError:
     from .compat.counter import Counter
     from .compat.ordereddict import OrderedDict
 
+from contextdecorator import ContextDecorator
+
 # Internal imports
 from .patch import install, reset
 from .persist import load_cassette, save_cassette
 from .serializers import yamlserializer
 from .matchers import requests_match, url, method
+from .errors import UnhandledHTTPRequestError
 
 
-class Cassette(object):
+class Cassette(ContextDecorator):
     '''A container for recorded requests and responses'''
 
     @classmethod
@@ -71,9 +74,11 @@ class Cassette(object):
                 if self.play_counts[index] == 0:
                     self.play_counts[index] += 1
                     return response
-        # I decided that a KeyError is the best exception to raise
-        # if the cassette doesn't contain the request asked for.
-        raise KeyError
+        # The cassette doesn't contain the request asked for.
+        raise UnhandledHTTPRequestError(
+            "The cassette (%r) doesn't contain the request (%r) asked for"
+            % (self._path, request)
+        )
 
     def responses_of(self, request):
         '''
@@ -87,9 +92,11 @@ class Cassette(object):
 
         if responses:
             return responses
-        # I decided that a KeyError is the best exception to raise
-        # if the cassette doesn't contain the request asked for.
-        raise KeyError
+        # The cassette doesn't contain the request asked for.
+        raise UnhandledHTTPRequestError(
+            "The cassette (%r) doesn't contain the request (%r) asked for"
+            % (self._path, request)
+        )
 
     def _as_dict(self):
         return {"requests": self.requests, "responses": self.responses}
